@@ -20,7 +20,8 @@ from .constants import LOG_LEVEL, LOG_FORMAT, DEFAULT_COT_PORT  # NOQA
 from .exceptions import UnsupportedEvent  # NOQA
 
 from .classes import (Event, Point, Detail, UID, Contact, EventType,  # NOQA
-                      AtomEventType, DataEventType, NetworkClient)
+                      AtomEventType, DataEventType, NetworkClient, Track,
+                      Remarks)
 
 from .functions import parse_event_type  # NOQA
 
